<div align="center">

# `fossiler v0.0.1` : a suite tool of fossils finding
**Hengchi Chen**

[**Bioinformatics & Evolutionary Genomics Group**](https://www.vandepeerlab.org/people/heche)**, VIB-UGent Center for Plant Systems Biology**

[**Fossil Justifications**](#Fossil-Justifications) |
[**References**](#References)
</div>

## Fossil Justifications
Below we give a detailed justification for each accepted fossil regarding the phylogenetic assignment and age bounds.

:leaves: and :microscope: denote macrofossils and microfossils, respectively.

:leaves: **${\text{\color{green} Fossil \ No.0}}$**

**Brief Desription:** The oldest fossil found in Nymphaeales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Nymphaeites choffatii*, young leaves (specimen 184-Pb. DBAV-UERJ), mature leaves (180a,b-Pb. DBAV-UERJ with an incomplete petiole; 181a,b-183-Pb. DBAV-UERJ), aggregates of roots still showing calyptra (185-190-Pb, DBAV-UERJ), Parnaíba Basin, Codó Formation, Cretaceous to of Brazil.

**Phylogenetic Justification:** This genus *Nymphaeites* was defined to be distinguished with non-peltate leaves with palmate veins branching at acute angles by Heer at 1870. (Bell, 1949) extended the diagnosis of *Nymphaeites* to non-peltate leaves with mixed pinnate and palmate veins as well as peltate and subpeltate leaves with similar venation and a typical petiole, since the secondary vein branches in palmate leaves may suggest a pinnate arrangement. (L. Duarte and R.Silva Santos, 1993) described the leaf remnants found at Parnaíba Basin with common features of symmetrical, orbicular peltate to wide obvate (1.2:1), base symmetrical, rounded to normal obtuse, teeth found along the upper two-thirds of the margin but not along the lateral basal portions, petiole strong and thick, preserved portions about 1.1cm long and 0.6cm width, petiolar insertion at the base of the blade, and specimen-specific features of margin dentate, teeth with a sharp apex, the basal and apical portions straight (182-Pb. DBAV-UERJ) and concave (181-184-Pb. DBAV-UERJ). While the root remnants therein were found to have two distinguished types of arrangement, main roots bearing thin and unbranched secondary roots with preserved calyptras, as well as overlapping aggregates also with preserved calyptras. The representation of leaf and root remnants suggested its assignment to *Nymphaeites choffatii*, according to (L. Duarte and R.Silva Santos, 1993).

**Age Justification:** The sedimentary rock from Parnaíba Basin, Codó Formation was thought to be of Aptian/Albian age (Lima, 1982). Based on numerous findings of the *Nymphaeites* fossil in shales of Aptian age, Duarte and R.Silva Santos suggested the age of the *Nymphaeites* fossil to be within Aptian. Thus, we use 121.4-113.0 mya as the age bound for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.1}}$**

**Brief Desription:** The oldest fossil found in Austrobaileyales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Cretacaeiporites cf. mulleri*, pollen grains on sample CAS-7, Araripe Basin, Rio da Batateira Formation, Cretaceous of Brazil.

**Phylogenetic Justification:** (Ulrich Heimhofer and Peter-A. Hochuli, 2010) proposed the fossil assignment as *Cretacaeiporites cf. mulleri* based on the observed morphology using Olympus BX 51 microscope.

**Age Justification:** The stratigraphic position of the Rio da Batateira Formation is confined by the occurrences of a number of age-diagnostic gymnosperm pollen taxa including *Afropollis aff. jardinus*, *A. jardinus* and *Sergipea cf. variverrucata* as well as the spore *Crybelosporites pannuceus*. According to (Doyle et al., 1982 and Doyle et al., 1992), the dominance of the heteropolar inaperturate taxon *Afropollis aff. jardinus* and the absence of zonosulcate forms (*A. zonatus* and *A. aff. zonatus*) indicate a late early Aptian (*A. aff. jardinus*) or younger age (*A. jardinus*). In the Rio da Batateira Formation, the maximum abundances of heteropolar *Afropollis* forms reach up to 17% of the whole palynoflora. According to the Northern Gabon reference record of (Doyle et al., 1982), this peak may be part of the second *Afropollis* maximum in palynozone C-X,which covers the uppermost Aptian–Lower Albian interval. (Pons et al., 1996) proposed a late Aptian age for the “Fundão” unit located below the Rio da Batateira Formation. While (Coimbra et al., 2002) also proposed an late Aptian *S. variverrucata* palynozone for the Rio da Batateira Formation. Based on the essentially continuous occurrence of *S. variverrucata* in core material covering the Crato, Ipubi and Santana Formations, (Regali, 2001) and (Rios-Netto and Regali, 2007) argued in favour of an Aptian age for the entire succession. Desipte the age uncertainty concerning the Santana Formation, a late Aptian age was agreed on the Rio da Batateira Formation. Thus, we used 121.4-113.0 mya as the age bound for this fossil, according to (Ogg et al., 2016) and the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.2}}$**

**Brief Desription:** The oldest fossil found in Piperales.

**Age Bounds:** 72.3 - 66.0 mya.

**Taxon & Specimen & Rock:** *Rosannia manika* Srivastava emend, spore-pollen labeled as MPEF–Palin 106 b: W45 on sample M3 of San Ramón section of the Lefipán Formation, Northwestern Patagonia, Cretaceous of Argentina.

**Phylogenetic Justification:** (Viviana et al., 2012) proposed the fossil assignment as *Rosannia manika* Srivastava emend following the revised generic diagnosis of (Srivastava and Braman 2010) featured with an obligate ana-ulcerate tetrad with calymmate exine and granulose supratectal ornamentation and a close morphological affinity with the pollen of extant *Lactoris fernandeziana* Phil, which was thus suggested to be assigned to Lactoridaceae.

**Age Justification:** Cluster analysis (Q mode) of (Viviana et al., 2012) revealed two stratigraphically wellordered major groups of samples: group A comprised of the Maastrichtian samples M1-M3, group B comprised of all early Danian samples. The highest proportional abundances of *Rosannia manika* Srivastava emend emerged at sample M3 as 0.389. Thus, we used 72.3 - 66.0 mya as the age bound for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.3}}$**

**Brief Desription:** The oldest fossil found in Canellales.

**Age Bounds:** 72.3 - 66.0 mya.

**Taxon & Specimen & Rock: *Pseudowinterapollis couperi* Krutzsch, 1970 emend, pollen grains labeled as MPM-MP 1952 101,3/8 on the Monte Chico Formation, Upper Cretaceous, Santa Cruz, Cretaceous of Argentina.

**Phylogenetic Justification:** (Leticia Karina Povilauskas, 2013) proposed the fossil assignment as *Pseudowinterapollis couperi* Krutzsch, 1970 emend, following the diagnosis of (Mildenhall, 1979).

**Age Justification:** Based on the stratigraphic distribution of the identified fossil species, mainly in Argentina and Antarctica, together with the preliminary analysis of spores, (Leticia Karina Povilauskas, 2013) suggested a Maastrichtian age of the studied sedimentary rock. Thus, we used 72.3 - 66.0 mya as the age bound for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.4}}$**

**Brief Desription:** The oldest fossil found in Magnoliales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Endressinia brasiliana* Mohr and Bernardes-de-Oliveira, leaves and flowers specimen labled as MB.PB.2001/1455, Araripe Basin, Crato Formation, Cretaceous of Brazil.

**Phylogenetic Justification:** Based on the characters featuring the genus *Endressinia*, small (less than or ca.10mm in diameter), multiparted flowers, consisting of tepals and spirally arranged inner organs, borne on a more or less flattened receptacle, towards the center, several spirally arranged rows of flat, elongated staminodes with marginal glands and in the center, ca.20 narrowly apocarpous follicles with small, distinct, glabrous stigmatic area, (Mohr and Bernardes‐de‐Oliveira, 2004) assigned the observed fossil displaying a branching axis with attached simple, narrowly ovate leaves and several terminal small flowers as *Endressinia brasiliana*, and suggested the genus *Endressinia* of being sister to Eupomatiaceae since only Himantandraceae and Eupomatiaceae among recent Magnoliales share the character of having staminodes with glands, which are broad in Eupomatia. The proability of representing an extinct lineage with convergent staminode morphology was also proposed therein.

**Age Justification:** As discussed in fossil No.1, a late Aptian age was also agreed on the Crato Formation. Thus, we used 121.4 - 113.0 mya as the age bound for this fossil, according to (Ogg et al., 2016) and the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.5}}$**

**Brief Desription:** The oldest fossil found in Laurales.

**Age Bounds:** 113.0 - 105.68 mya.

**Taxon & Specimen & Rock:** *Appomattoxia ancistrophora* gen. et sp. nov., fruit and pollen grains with holotype specimen PP44001 and more than 450 other specimens from Puddledock samples 82, 83, 142, 143, 151, 152, 156, palynological Subzone IIB, Tarmac Lone Star Industries Puddledock locality in the Potomac Group sequence of Virginia, Cretaceous of the United States.

**Phylogenetic Justification:** The genus *Appomattoxia* and fossil *Appomattoxia ancistrophora* was first established by (Friis et al., 1995) based on well-preserved fruiting units and associated pollen. Fruiting units are small, unilocular, and with a single, pendulous, orthotropous seed. The fruit surface is characterized by densely spaced unicellular spines with hooklike tips, which probably functioned in biotic dispersal. Pollen grains adhering to the stigmatic area of many specimens are monocolpate and tectate with granular to columellate infratectal structure. The fossil *Appomattoxia ancistrophora* shared an exclusive combination of characters with magnoliid taxa including Piperales, Laurales and Circaeasteraceae. Since *Appomattoxia ancistrophora* differs from extant Piperales in having a pendulous instead of erect ovule, and differs from extant *Circaeaster* in details of the fruit wall and the presence of monosulcate instead of tricolpate pollen, (Friis et al., 1995) suggested the genus *Appomattoxia* to be closest to Laurales.

**Age Justification:** The age of Potomac Group palynological Subzone IIB has not been established with certainty, although it is generally believed to fall within the Albian. (Doyle and Robbins, 1977) dated basal Subzone IIB of the Potomac Group to about the Early/Middle Albian boundary and middle Subzone IIB to late Middle Albian. Subsequent palynological correlations of the Potomac Group sequence with material from other areas for which there is better marine control indicate that Subzone IIB may extend down into the Early Albian ((Doyle, 1992). Palynological Subzone IIC, which overlies Subzone IIB, has been interpreted as latest Albian (Doyle and Robbins, 1977). The palynological Subzone IIB may therefore be as old as the Early Albian, and are probably not younger than the Middle Albian. Thus, we used 113.0 - 105.68 mya as the age bound for this fossil, according to (Scott, 2009) and the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:microscope: **${\text{\color{green} Fossil \ No.6}}$**

**Brief Desription:** The oldest fossil found in Chloranthales.

**Age Bounds:** 139.8 - 125.77 mya

**Taxon & Specimen & Rock:** *Clavatipollenites sp.* and *Clavatipollenites minutus*, spores and pollen grains, in well/slide K2C2B3, H19/0, K2C2B2, R23/0 and Z1C7B3, S21/3, *Bullasporis bifidum*/*Klukisporites scaberis* Palynozone, Helez Formation, Cores 1, 2, 3 and 5, Kurnub Group, Kokhav 2, Cretaceous coastal plain of Israel. 

**Phylogenetic Justification:** Two *Clavatipollenites sp.* and one *Clavatipollenites minutus* fossils were described in (Brenner and Bickoff, 1992). The assignment of *Clavatipollenites* followed the definition of (Brenner, 1963). While the *Clavatipollenites sp. A* is distinguished by the faintly striate apperance and similiar to the *Clavatipollenites sp. 1* found in Zone C-V1 from Africa.

**Age Justification:** *Clavatipollenites minutus* was found in Helez and Zeweira Formations. While *Clavatipollenites sp.* fossils were restricted to the Helez Formation. The Zeweira Formation was divided into two subzones based on the first occurrence of pollen types in core 6. Core 6 and 7 have very similar spore and pollen assemblages, but core 6 contains the first appearance of the lower marker form *Brenneripollis reticulatus* as well as the first occurrence of the tricolpate pollen and *Afropollis jardinus*. A late Barremian age is therefore suggested for the lower part of the Zeweira Formation (core 7), while the new forms mentioned above in core 6 suggest a early Aptian age. (Grader and Reiss, 1958) laid the foundation for the currently accepted stratigraphy of the Helez Formation by studying subsurface samples from the Helez 1, 2, 3 and Negba 1 wells, and used micro-and megafaunal evidence to date the basal Cretaceous. The dating results from microfauna suggested the age as late Valanginian to early Hauterivian. Specifically, the upper part of units L.CrIIa (Hm, H1, H2, H3) is interpreted to be early Hauterivian based on the presence of the ammonites *Leupoldia* and *Saynella*, while the lower part was determined to be of Valanginian age because it's immediately below early Hauterivian sediments and above Berriasian to Valanginian sediments of the L.CrI unit. Taking into account that *Clavatipollenites sp. B* emerged at H1 and H2, we suggested setting late Valanginian to early Hauterivian as the age of the fossil. The age bound was set as 139.8 - 125.77 mya for this fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.7}}$**

**Brief Desription:** The oldest fossil found in Commelinales.

**Age Bounds:** 56.0 - 33.9 mya.

**Taxon & Specimen & Rock:** *Eichhornia sp.*, megafossils in root and stem fragments, the Deccan Intertrappean beds, Eocene of India.

**Phylogenetic Justification:** (Patil and Singh, 1978) described and assigned the fossil as *Eichhornia sp.* affiliated to Pontederiaceae.

**Age Justification:** The sedimentary rock was dated as Eocene. Thus, we used 56.0 - 33.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.8}}$**

**Brief Desription:** The oldest fossil found in Zingiberales.

**Age Bounds:** 83.8 - 71.9 mya.

**Taxon & Specimen & Rock:** *Spirematospermum chandlerae*, macrofossils, Neuse River Cut-Off, Wayne County, Black Creek Formation, North Carolina, Cretaceous of the United States.

**Phylogenetic Justification:** (Friis et al., 1988) described the fossil as *Spirematospermum chandlerae*. (Andrews, 1970) assigned the genus *Spirematospermum* to be within Zingiberaceae based on the morphology of a fruit fossil deposited in Hordle, Hampshire, England.

**Age Justification:** The Black Creek Formation was dated as Campanian. Thus, we used 83.8 - 71.9 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

:leaves: **${\text{\color{green} Fossil \ No.9}}$**

**Brief Desription:** The oldest fossil found in Poales.

**Age Bounds:** 124.85 - 124.35 mya. 

**Taxon & Specimen & Rock:** *Eragrosites changii*, spikelets and panicle, Holotype: pl. ll-2 (PB17803), Yixian Formation (Jehol Group), Cretaceous of China.

**Phylogenetic Justification:** (Cao et al., 1998) described the morphology of the fossil as larger panicle, about 14 cm in incompletely preserved length and at least 10 cm in width; rachis about 3 mm wide at the base, narrowing gradually to the upper portion of inflorescence, oppositely branching 3 times, apart from each other, with longitudinal striations and glandula-like appendages on the surface of rachis and branches; bracts absent. Spikelets arranged in panicle, ovate to elongatedly elliptical in outline, about 5 mm long, composed of the biserial "florets", likely bearing two glumes at its base. The spikelets and inflorescences of the present specimens extremely resemble those of the existing plant *Eragrostis Wolf* of Poaceae. The difference between them is that the inflorescence branches of the latter are generally alternate and sometimes partly opposite even verticillate, while those of the former are consistently opposite. The new genus was accordingly named as *Eragrosties* for its similarity to *Eragrostis*.

**Age Justification:** The Jianshangou bed was dated by (Swisher et al., 1999) using <sup>40</sup>Ar/<sup>39</sup>Ar method as 124.60 ± 0.25 mya for Sample P1T-2 and 124.61 ± 0.20 mya for Sample P4T-1. Here, we used the union set of the two estimates and set the age of the fossil as 124.85 - 124.35 mya.

:microscope: **${\text{\color{green} Fossil \ No.10}}$**

**Brief Desription:** The oldest fossil found in Arecales.

**Age Bounds:** 121.4 - 113.0 mya.

**Taxon & Specimen & Rock:** *Spinizonocolpites sp.*, palynomorphs, Bajo Comisión, Rio Mayer Formation, Cretaceous of Argentina.

**Phylogenetic Justification:** (Archangelsky et al., 2012) classified the fossil as to *Spinizonocolpites*. (Huang et al., 2023) based on the observation of the scanned electron microscopy micrographs of sporomorphs assigned the *Spinizonocolpites* to Arecaceae.

**Age Justification:** The age of Rio Mayer Formation was dated as Upper Aptian (Archangelsky et al., 2012). Thus, we used the age 121.4 - 113.0 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/). 

:leaves: **${\text{\color{green} Fossil \ No.11}}$**

**Brief Desription:** The oldest fossil found in Asparagales.

**Age Bounds:** 27.82 - 15.97 mya.

**Taxon & Specimen & Rock:** *Phormium sp.*, leaf litter, cuticle and pollen grain, Newvale Mine leaf beds, fossil site F45/f0394, Newvale assemblage, Gore Lignite Measures, the Late Oligocene to Early Miocene southern New Zealand.

**Phylogenetic Justification:** All of the macrofossils reported by (Ferguson et al., 2010) have exceptionally well-preserved cuticle. (Ferguson et al., 2010) decided the phylogenetic assignment of the fossil *Phormium sp.* by the observation of its partial leaf, cuticle, and pollen grain from Newvale Mine leaf beds. (Ferguson et al., 2010) regarded it as members of Asparagaceae.

**Age Justification:** The age of the middle Gore Lignite Measures is Late Oligocene or Early Miocene (Waitakian to Altonian Stage) based on studies of palynofloras of Oligocene and Miocene strata of Otago and Southland by (Pocknall and Mildenhall, 1984) and (Mildenhall and Pocknall, 1989). Given the close association between marine strata of Waitakian age and the lower and middle Gore Lignite Measures in the Waimumu area (Isaac and Lindqvist, 1990), (Ferguson et al., 2010) suggested the age of the lignite as Waitakian (late Oligocene to early Miocene). Thus, we used the age 27.82 - 15.97 mya as the age of the fossil, according to the [International Chronostratigraphic Chart v2023/04](https://stratigraphy.org/).

## References
Barreda VD, Cúneo NR, Wilf P, Currano ED, Scasso RA, et al. (2012) Cretaceous/Paleogene Floral Turnover in Patagonia: Drop in Diversity, Low Extinction, and a Classopollis Spike. PLOS ONE, 7(12): e52455.

Bell, W. A. (1949). Uppermost Cretaceous and Paleocene floras of western Alberta. Bulletin, Geological Survey of Canada, 13: 1–231.

Brenner, G.J. (1963). The spores and pollen of the Potomac Group of Maryland. Maryland Department of Geology, Mines and Water Resources, 27: 215.

Brenner, G. J. and Bickoff, I. S. (1992). Palynology and Age of the Lower Cretaceous Basal Kurnub Group from the Coastal Plain to the Northern Negev of Israel. Palynology, 16: 137–185.

David K. Ferguson, Daphne E. Lee, Jennifer M. Bannister, Reinhard Zetter, Gregory J. Jordan, Norbert Vavra, Dallas C. Mildenhall (2010). The taphonomy of a remarkable leaf bed assemblage from the Late Oligocene–Early Miocene Gore Lignite Measures, southern New Zealand. International Journal of Coal Geology, 83(2-3): 173-181.

de Lima, M. R. (1982). Palinologia da Formação Codó na região de Codó, Maranhão. Boletim IG, 13: 116-128.

Doyle, J.A. (1992). Revised palynological correlations of the lower Potomac Group (USA) and the Cocobeach sequence of Gabon (Barremian–Aptian). Cretaceous Research, 13: 337–349.

Doyle, J.A., P. Biens, A. Doerenkamp and S. Jardiné. (1977). Angiosperm pollen from the pre-Albian Lower Cretaceous of Equatorial Africa. Bulletin Centres Rescherches Exploration-Production Elf-Aquitaine, 1:451-473.

Doyle, J.A., Jardiné, S., Doerenkamp, A. (1982). *Afropollis*, a new genus of early angiosperm pollen, with notes on the Cretaceous palynostratigraphy and palaeoenvironments of northern Gondwana. Bulletin. Centres de Recherches Exploration-Production Elf-Aquitaine, 6: 39–117.

E. M. Friis, K. R. Pedersen, and P. R. Crane. (1995). *Appomattoxia ancistrophora* gen. et sp. nov., a new Early Cretaceous plant with similarities to Circaeaster and extant Magnoliidae. American Journal of Botany, 82(7):933-943.

E. M. Friis, P. R. Crane, and K. R. Pedersen. (1988). Reproductive structures of Cretaceous Platanaceae. Biologiske Skrifter Det Kongelige Danske Videnskskabernes Selskab, 31:1-55.

Huasheng Huang, Robert J. Morley, Alexis Licht, Guillaume Dupont-Nivet, Daniel Pérez-Pinedo, Jan Westerweel, Zaw Win, Day Wa Aung, Eko Budi Lelono, Galina N. Aleksandrova, Ramesh K. Saxena, Carina Hoorn (2023). A proto-monsoonal climate in the late Eocene of Southeast Asia: Evidence from a sedimentary record in central Myanmar. Geoscience Frontiers, 14(1): 101457.

H. N. Andrews. (1970). Index of Generic Names of Fossil Plants, 1820-1965. Geological Survey Bulletin, 1-354.

Isaac, M.J. and Lindqvist, J.K. (1990). Geology and lignite resources of the East Southland Group, New Zealand. New Zealand Geological Survey Bulletin, 101: 1–202.

Grader, P. and Reiss Z. (1958). On the Lower Cretaceous of Heletz Area. Geological Survey of Israel, 16: 14.

L. Duarte and R.Silva Santos (1993). Plant and fish megafossils of the Codó Formation, Parnaıba Basin, NE Brazil. Cretaceous Research, 14(6): 735-746.

Leticia Karina Povilauskas (2013). Palinología de Angiospermas de la Formación Monte Chico (Cretácico Superior) de la Provincia de Santa Cruz, Argentina. Revista Brasileira de Paleontologia 16(1):115-126.

L. Povilauskas. (2013). Palinología de Angiospermas de la Formación Monte Chico (Cretácico Superior) de la Provincia de Santa Cruz, Argentina. Revista Brasileira de Paleontologia, 16(1):115-126.

Mildenhall, D.C. (1979). Palynology of the Waipipian and Hautawan Stages (Pliocene and Pleistocene), Wanganui, New Zealand (note). New Zealand Journal of Geology and Geophysics, 21:775-777.

Mildenhall, D.C. and Pocknall, D.T. (1989). Miocene–Pleistocene spores and pollen from Central Otago, South Island, New Zealand. New Zealand Geological Survey Paleontological Bulletin, 59: 1–128.

Ogg, James,  Ogg, Gabi and Gradstein, Felix. (2016). A Concise Geologic TimeScale.

Patil, G. V., & Singh, R. B. (1978). Fossil Eichhornia from the Eocene Deccan Intertrappean beds, India. Palaeontographica Abteilung B-Palaophytologie.

Pocknall, D.T. and Mildenhall, D.C. (1984). Late Oligocene–early Miocene spores and pollen from Southland, New Zealand. New Zealand Geological Survey Paleontological Bulletin, 51: 1–66.

Pons, D., Berthou, P.Y., Filgueira, J.B.M., Sampaio, J.J.A. (1996). Palynologie des unités lithostratigraphique “Fundao”, “Crato” et “Ipubi” (Aptien supérieur à Albien inférieurmoyen, Bassin d'Araripe, NE du Brésil): enseignements paléoécologiques, stratigraphiques et climatologiques. In: Jardiné, S., Klasz, I., Debenet, J.-P. (Eds.), Géologie de l'Afrique et de l'Atlantique Sud. Elf Aquitaine Memoire, Pau, pp. 383–401.

Regali, M.S.P. (2001). Palinoestratigrafia dos sedimentos Cretácicos da Bacia do Araripe e das Bacias Interiores do Nordeste—Brasil. In: Barros, L.M., Nuvens, P.C., Filgueira, J.B.M. (Eds.), I e II Simpósios Sobre a Bacia do Araripe e Bacias Interiores do Nordeste. Universidade Regional do Cariri—URCA, Crato, pp. 101–108.

Rios-Netto, A.M., Regali, M.S.P. (2007). Estudo bioestratigráfico, paleoclimático e paleoambiental do intervalo Alagoas (Cretáceo Inferior) da Bacia do Araripe, Nordeste do Brasil (Poço 1-PS-11-CE). Paleontologia: Cenários de Vida. Interciência, Rio de Janeiro, pp. 481–490.

R. N. Lakhanpal, H. K. Maheshwari, and N. Awasthi. (1976). A Catalogue of Indian Fossil Plants. 1-318.

S. Archangelsky, A. Archangelsky, and G. Cladera. (2012). Palinología y paleoambientes en el perfil de Bajo Comisión (Cretácico), provincia de Santa Cruz, Argentina. Revista del Museo Argentino de Ciencias Naturales, 14(1):23-39.

Satish K. Srivastava, Dennis R. Braman (2010). The revised generic diagnosis, specific description and synonymy of the Late Cretaceous *Rosannia manika* from Alberta, Canada: Its phytogeography and affinity with family Lactoridaceae. Review of Palaeobotany and Palynology, 159(1–2): 2-13.

Scott R.W. (2009). Uppermost Albian biostratigraphy and chronostratigraphy. Carnets de Géologie / Notebooks on Geology, Brest, Article 2009/03 (CG2009_A03)

Swisher, C.C., Wang, Y.Q., Wang, X.L., Xu, X. and Wang, Y. (1999). Cretaceous age for the feathered dinosaurs of Liaoning, China. Nature, 400: 58–61.

Ulrich Heimhofer, Peter-A. Hochuli (2010). Early Cretaceous angiosperm pollen from a low-latitude succession (Araripe Basin, NE Brazil). Review of Palaeobotany and Palynology, 161(3-4): 105-126.

Zhengyao Cao, Shunqing Wu, Ping'an and Li Jieru Zhang (1998). Discovery of fossil monocotyledons from Yixian Formation, western Liaoning. Chinese Science Bulletin, 43(3): 230-233.
